#!/usr/bin/env python
"""Utils."""
from os import getenv


class GetEnvError(Exception):
    """Exception raised for getenv errors."""


def get_env(key: str) -> str:
    """Get environment variable or raise an error."""
    if value := getenv(key):
        return value

    msg = f"Please setup {key} in environment variables."
    raise GetEnvError(msg)



#!/usr/bin/env python
"""Types."""
from datetime import datetime
from typing import NamedTuple

FBTypes = str | float | datetime | None
Dataset = list[dict[str, FBTypes]]


class CompletedTransaction(NamedTuple):
    """The return value from execute(), representing a transaction that has finished."""

    host: str
    db: str
    user: str
    returncode: int
    error: str
    query: str
    params: tuple
    data: Dataset
